@@ -5,7 +5,6 @@ import (
 	"errors"
 	"fmt"
 	"maps"
-	"slices"
 
 	"github.com/google/shlex"
 	"github.com/samber/lo"
@@ -401,18 +400,8 @@ func makeEphemeralConsoleMachine(ctx context.Context, app *fly.AppCompact, appCo
 func determineEphemeralConsoleMachineGuest(ctx context.Context, appConfig *appconfig.Config) (*fly.MachineGuest, error) {
 	var guest *fly.MachineGuest
 
-	haveConsoleVMSection := 0 <= slices.IndexFunc(
-		appConfig.Compute,
-		func(c *appconfig.Compute) bool {
-			return slices.Index(c.Processes, "console") >= 0
-		},
-	)
-	if haveConsoleVMSection {
-		groupConfig, err := appConfig.ToMachineConfig("console", nil)
-		if err != nil {
-			return nil, fmt.Errorf("failed to check Machine configuration for the 'console' group: %w", err)
-		}
-		guest = groupConfig.Guest
+	if compute := appConfig.ComputeForGroup("console"); compute != nil {
+		guest = compute.MachineGuest
 	}
 
 	guest, err := flag.GetMachineGuest(ctx, guest)
