@@ -7,12 +7,14 @@ import (
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/extensions/arcjet"
 	"github.com/superfly/flyctl/internal/command/extensions/enveloop"
+	"github.com/superfly/flyctl/internal/command/extensions/fly_mysql"
 	"github.com/superfly/flyctl/internal/command/extensions/kafka"
 	"github.com/superfly/flyctl/internal/command/extensions/kubernetes"
 	sentry_ext "github.com/superfly/flyctl/internal/command/extensions/sentry"
 	"github.com/superfly/flyctl/internal/command/extensions/supabase"
 	"github.com/superfly/flyctl/internal/command/extensions/tigris"
 	"github.com/superfly/flyctl/internal/command/extensions/vector"
+	"github.com/superfly/flyctl/internal/command/extensions/wafris"
 )
 
 func New() (cmd *cobra.Command) {
@@ -34,6 +36,8 @@ func New() (cmd *cobra.Command) {
 		vector.New(),
 		enveloop.New(),
 		arcjet.New(),
+		fly_mysql.New(),
+		wafris.New(),
 	)
 	return
 }
