@@ -10,6 +10,7 @@ import (
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/command/apps"
 	"github.com/superfly/flyctl/internal/flag"
+	"github.com/superfly/flyctl/internal/flyutil"
 	mach "github.com/superfly/flyctl/internal/machine"
 	"github.com/superfly/flyctl/internal/prompt"
 )
@@ -40,7 +41,7 @@ func newAddFlycast() *cobra.Command {
 
 func runAddFlycast(ctx context.Context) error {
 	var (
-		client  = fly.ClientFromContext(ctx)
+		client  = flyutil.ClientFromContext(ctx)
 		appName = appconfig.NameFromContext(ctx)
 	)
 
@@ -92,37 +93,36 @@ func doAddFlycast(ctx context.Context) error {
 		}
 
 		conf := machine.Config
-		conf.Services =
-			[]fly.MachineService{
-				{
-					Protocol:     "tcp",
-					InternalPort: bouncerPort,
-					Ports: []fly.MachinePort{
-						{
-							Port: &bouncerPort,
-							Handlers: []string{
-								"pg_tls",
-							},
-							ForceHTTPS: false,
+		conf.Services = []fly.MachineService{
+			{
+				Protocol:     "tcp",
+				InternalPort: bouncerPort,
+				Ports: []fly.MachinePort{
+					{
+						Port: &bouncerPort,
+						Handlers: []string{
+							"pg_tls",
 						},
+						ForceHTTPS: false,
 					},
-					Concurrency: nil,
 				},
-				{
-					Protocol:     "tcp",
-					InternalPort: pgPort,
-					Ports: []fly.MachinePort{
-						{
-							Port: &pgPort,
-							Handlers: []string{
-								"pg_tls",
-							},
-							ForceHTTPS: false,
+				Concurrency: nil,
+			},
+			{
+				Protocol:     "tcp",
+				InternalPort: pgPort,
+				Ports: []fly.MachinePort{
+					{
+						Port: &pgPort,
+						Handlers: []string{
+							"pg_tls",
 						},
+						ForceHTTPS: false,
 					},
-					Concurrency: nil,
 				},
-			}
+				Concurrency: nil,
+			},
+		}
 
 		err = mach.Update(ctx, machine, &fly.LaunchMachineInput{
 			Config: conf,
